\name{createFilename}
\alias{createFilename}
\title{create a file path based off a given format.}
\usage{
  createFilename(format, fPath = format, base = "",
    extraTokens = list())
}
\arguments{
  \item{format}{A file format optionally containing the
  following tokens, which will be replaced from the "base"
  and "fPath" arguments.  \describe{ item{\%d}{the parent
  directory of the file in fPath} item{\%D}{dirname(fPath)}
  item{\%e}{the extension of the file in fPath (default
  "tif")} item{\%f}{the file name of the file in fPath}
  item{\%B}{the "base" parameter supplied in the
  arguments.} }}

  \item{fPath}{A filepath to grab "\%d", "\%D", etc from.}

  \item{base}{what to be used as "\%B" in "format".}

  \item{extraTokens}{A named list, with further token=value
  pairs to be substituted in `format`.  Does not include
  the '\%', so if we wanted '\%a' to be substitued by
  'foobar', we would specify \code{list(a='foobar')}.  The
  value will be coerced to character, unless it is a
  function, in which case it will be executed with
  arguments `fPath` and `base`.}
}
\value{
  a file name with all the tokens substituted in.
}
\description{
  create a file path based off a given format.
}
\examples{
createFilename('\%B/\%d/\%f_new.\%e', fPath='/path/to/file.txt',
                base='/new/root/dir')
 # returns '/new/root/dir/to/file_new.txt'

createFilename('\%D/\%f_smaller.jpg', fPath='~/pictures/img.jpg')
 # returns '~/pictures/img_smaller.jpg'

# demonstrate the ... parameter. '\%a' is substituted with '_',
# '\%b' is substituted with nchar('foobar.txt').
createFilename('\%f\%a\%b.png', fPath='foobar.txt',
               extraTokens=list(a='_', b=function(fpath, base) { nchar(fpath) }))
# returns 'foobar_10.png'
}
\seealso{
  Other file: \code{\link{getExtension}},
  \code{\link{getFilename}},
  \code{\link{getUniqueFilename}},
  \code{\link{makeIfNotExists}}
}

